::: {#navbar .navbar .navbar-default .navbar-fixed-top role="navigation"}
::: {.container}
::: {.navbar-header}
[]{.icon-bar} []{.icon-bar} []{.icon-bar}

<div>

[![](../_static/img/RAIcon.png)](/runestone/default/user/login){.brand-logo}
[fopp](../index.html){#rs-book-toc-link .navbar-brand}

</div>
:::

::: {.navbar-collapse .collapse .navbar-ex1-collapse}
-   
-   []{#ad_warning}
-   []{#browsing_warning}
-   
-   [*[Search]{.visuallyhidden
    aria-label="Search"}*](#){.dropdown-toggle}
    -   [Table of Contents](../index.html)

    -   [Book Index](../genindex.html)

    -   

    -   ::: {.input-group}
        :::
-   
-   [*[User]{.visuallyhidden aria-label="User"}*](#){.dropdown-toggle}
    -   []{.loggedinuser}

    -   

    -   [Course Home](/ns/course/index)

    -   [Assignments](/assignment/student/chooseAssignment)

    -   [Practice](/runestone/assignments/practice)

    -   [[Peer Instruction
        (Instructor)](/runestone/peer/instructor.html)]{#inst_peer_link}

    -   [Peer Instruction (Student)](/runestone/peer/student.html)

    -   

    -   [Change Course](/runestone/default/courses)

    -   

    -   [[Instructor\'s
        Page](/runestone/admin/index)]{#ip_dropdown_link}

    -   [Progress Page](/runestone/dashboard/studentreport)

    -   

    -   [Edit Profile](/runestone/default/user/profile){#profilelink}

    -   [Change
        Password](/runestone/default/user/change_password){#passwordlink}

    -   [Register](/runestone/default/user/register){#registerlink}

    -   [Login](#)

    -   ::: {.slider .round}
        :::

        Dark Mode
-   
-   [[*[Scratch Activecode]{.visuallyhidden
    aria-label="Scratch Activecode"}*](javascript:runestoneComponents.popupScratchAC())]{#scratch_ac_link}
-   
-   [*[Help]{.visuallyhidden aria-label="Help"}*](#){.dropdown-toggle}
    -   [FAQ](http://runestoneinteractive.org/pages/faq.html)
    -   [Instructors Guide](https://guide.runestone.academy)
    -   
    -   [About Runestone](http://runestoneinteractive.org)
    -   [Report A
        Problem](/runestone/default/reportabug?course=fopp&page=toctree)
-   

```{=html}
<!-- -->
```
-   
-   [This Chapter](../index.html){.dropdown-toggle}
    -   [6.1 Introduction: Sequences](intro-Sequences.html){.reference
        .internal}
    -   [6.2 Strings, Lists, and
        Tuples](StringsandLists.html){.reference .internal}
    -   [6.3 Index Operator: Working with the Characters of a
        String](IndexOperatorWorkingwiththeCharactersofaString.html){.reference
        .internal}
    -   [6.4 Disambiguating \[\]: creation vs
        indexing](DisabmiguatingSquareBrackets.html){.reference
        .internal}
    -   [6.5 Length](Length.html){.reference .internal}
    -   [6.6 The Slice Operator](TheSliceOperator.html){.reference
        .internal}
    -   [6.7 Concatenation and
        Repetition](ConcatenationandRepetition.html){.reference
        .internal}
    -   [6.8 Count and Index](CountandIndex.html){.reference .internal}
    -   [6.9 Splitting and Joining
        Strings](SplitandJoin.html){.reference .internal}
    -   [6.10 Exercises](Exercises.html){.reference .internal}
    -   [6.11 Chapter Assessment](week2a1.html){.reference .internal}
-   
-   
:::
:::
:::

::: {#continue-reading .container}
:::

::: {#main-content .container role="main"}
::: {#sequences .section}
[6. ]{.section-number}Sequences[¶](#sequences "Permalink to this heading"){.headerlink}
=======================================================================================

::: {.toctree-wrapper .compound}
[Sequences]{.caption-text}

-   [6.1. Introduction: Sequences](intro-Sequences.html){.reference
    .internal}
    -   [6.1.1. Learning
        Goals](intro-Sequences.html#learning-goals){.reference
        .internal}
    -   [6.1.2. Objectives](intro-Sequences.html#objectives){.reference
        .internal}
-   [6.2. Strings, Lists, and Tuples](StringsandLists.html){.reference
    .internal}
    -   [6.2.1. Strings](StringsandLists.html#strings){.reference
        .internal}
    -   [6.2.2. Lists](StringsandLists.html#lists){.reference .internal}
    -   [6.2.3. Tuples](StringsandLists.html#tuples){.reference
        .internal}
-   [6.3. Index Operator: Working with the Characters of a
    String](IndexOperatorWorkingwiththeCharactersofaString.html){.reference
    .internal}
    -   [6.3.1. Index Operator: Accessing Elements of a List or
        Tuple](IndexOperatorWorkingwiththeCharactersofaString.html#index-operator-accessing-elements-of-a-list-or-tuple){.reference
        .internal}
-   [6.4. Disambiguating \[\]: creation vs
    indexing](DisabmiguatingSquareBrackets.html){.reference .internal}
-   [6.5. Length](Length.html){.reference .internal}
-   [6.6. The Slice Operator](TheSliceOperator.html){.reference
    .internal}
    -   [6.6.1. List
        Slices](TheSliceOperator.html#list-slices){.reference .internal}
    -   [6.6.2. Tuple
        Slices](TheSliceOperator.html#tuple-slices){.reference
        .internal}
-   [6.7. Concatenation and
    Repetition](ConcatenationandRepetition.html){.reference .internal}
-   [6.8. Count and Index](CountandIndex.html){.reference .internal}
    -   [6.8.1. Count](CountandIndex.html#count){.reference .internal}
    -   [6.8.2. Index](CountandIndex.html#index){.reference .internal}
-   [6.9. Splitting and Joining Strings](SplitandJoin.html){.reference
    .internal}
-   [6.10. Exercises](Exercises.html){.reference .internal}
    -   [6.10.1. Contributed
        Exercises](Exercises.html#contributed-exercises){.reference
        .internal}
-   [6.11. Chapter Assessment](week2a1.html){.reference .internal}
:::
:::

::: {style="width: 100%"}
::: {ea-publisher="runestoneacademy" ea-type="image" style="display: flex; justify-content: center"}
:::
:::

::: {#scprogresscontainer}
You have attempted []{#scprogresstotal} of []{#scprogressposs}
activities on this page

::: {#subchapterprogress aria-label="Page progress"}
:::
:::

-   [[](../PythonTurtle/week1a3.html)]{#relations-prev}
-   [[](intro-Sequences.html)]{#relations-next}
:::

::: {.container}
[]{#numuserspan}[]{.loggedinuser} \| [Back to top](#)

© Copyright 2017 bradleymiller. Created using
[Runestone](http://runestoneinteractive.org/) 7.2.10.
:::
